summaryrefslogtreecommitdiffstats
path: root/lib
diff options
context:
space:
mode:
authorHolger Levsen <holger@debian.org>2015-04-26 17:10:05 +0000
committerHolger Levsen <holger@debian.org>2015-04-26 17:10:05 +0000
commitc727feceffe592373d5b795351e6ad3fe47060e6 (patch)
tree9d443a141a3441fa6024104f3a128ca19abcaf63 /lib
parentdcdae422649ba3834bea55beaec586716ba10836 (diff)
add support for oldoldstable and stretch and make jessie the new stable release
git-svn-id: svn+ssh://svn.debian.org/svn/secure-testing@33868 e39458fd-73e7-0310-bf30-c45bca0a0e42
Diffstat (limited to 'lib')
-rw-r--r--lib/python/debian_support.py2
-rw-r--r--lib/python/dist_config.py5
-rw-r--r--lib/python/security_db.py21
3 files changed, 17 insertions, 11 deletions
diff --git a/lib/python/debian_support.py b/lib/python/debian_support.py
index c820b04d33..f4c42241e0 100644
--- a/lib/python/debian_support.py
+++ b/lib/python/debian_support.py
@@ -194,7 +194,7 @@ class Release(PseudoEnum): pass
def listReleases():
releases = {}
rels = ("experimental", # For use in [brackets] in the list files.
- "potato", "woody", "sarge", "etch", "lenny", "squeeze", "wheezy", "jessie", "sid")
+ "potato", "woody", "sarge", "etch", "lenny", "squeeze", "wheezy", "jessie", "stretch", "sid")
for r in range(len(rels)):
releases[rels[r]] = Release(rels[r], r)
Release.releases = releases
diff --git a/lib/python/dist_config.py b/lib/python/dist_config.py
index 333efff583..0ede8e03d9 100644
--- a/lib/python/dist_config.py
+++ b/lib/python/dist_config.py
@@ -41,6 +41,7 @@ def apply_config():
squeeze_archs = common_archs + ['s390','ia64','kfreebsd-amd64','kfreebsd-i386','sparc' ]
wheezy_archs = squeeze_archs + ['armhf','s390x' ]
jessie_archs = common_archs + [ 'arm64','armhf','ppc64el' ]
+ stretch_archs = jessie_archs
add_release(name='squeeze',
architectures=squeeze_archs,
@@ -54,6 +55,10 @@ def apply_config():
architectures=jessie_archs,
)
+ add_release(name='stretch',
+ architectures=stretch_archs,
+ )
+
add_release(name='sid',
architectures=jessie_archs,
)
diff --git a/lib/python/security_db.py b/lib/python/security_db.py
index 51262e495c..b316594756 100644
--- a/lib/python/security_db.py
+++ b/lib/python/security_db.py
@@ -367,7 +367,7 @@ class DB:
AND sp.release = 'jessie' AND sp.subrelease = ''
ORDER BY sp.name, st.urgency, st.bug_name""")
- for (name, nickname) in (('stable', 'wheezy'), ('oldstable', 'squeeze'),):
+ for (name, nickname) in (('stable', 'jessie'), ('oldstable', 'wheezy'), ('oldoldstable', 'squeeze'),):
cursor.execute(
"""CREATE TEMPORARY VIEW %s_status AS
SELECT DISTINCT sp.name AS package, st.bug_name AS bug,
@@ -452,7 +452,7 @@ class DB:
return -1
self.db.createscalarfunction("subreleasepart_to_number", subreleasepart_to_number, 1)
- releases = ['potato', 'woody', 'sarge', 'etch', 'lenny', 'squeeze', 'wheezy', 'jessie', 'sid']
+ releases = ['potato', 'woody', 'sarge', 'etch', 'lenny', 'squeeze', 'wheezy', 'jessie', 'stretch', 'sid']
def release_to_number(u):
try:
return releases.index(u)
@@ -1129,9 +1129,10 @@ class DB:
"SELECT name FROM bugs WHERE NOT not_for_us"):
self._calcUnstable(c, bug_name)
- self._calcTesting(c, bug_name, 'testing', 'jessie')
- self._calcTesting(c, bug_name, 'stable', 'wheezy')
- self._calcTesting(c, bug_name, 'oldstable', 'squeeze')
+ self._calcTesting(c, bug_name, 'testing', 'stretch')
+ self._calcTesting(c, bug_name, 'stable', 'jessie')
+ self._calcTesting(c, bug_name, 'oldstable', 'wheezy')
+ self._calcTesting(c, bug_name, 'oldoldstable', 'squeeze')
return result
@@ -1580,7 +1581,7 @@ class DB:
store_value('release/1/' + release, '\n'.join(result))
- for release in ('sid', 'squeeze', 'wheezy', 'jessie'):
+ for release in ('sid', 'squeeze', 'wheezy', 'jessie', 'stretch'):
gen_release(release)
result = result_start
@@ -1593,7 +1594,7 @@ class DB:
def calculateDebsecan(self):
"""Calculate all debsecan data."""
- for release in ('', 'squeeze', 'wheezy', 'jessie'):
+ for release in ('', 'squeeze', 'wheezy', 'jessie', 'stretch'):
self.calculateDebsecan0(release)
self.calculateDebsecan1()
@@ -1630,7 +1631,7 @@ class DB:
"""SELECT release_name(release, subrelease, archive)
AS release, version FROM source_packages
WHERE name = ?
AND release IN ('squeeze', 'wheezy', 'jessie', 'sid')
GROUP BY release, version
ORDER BY release_to_number(release), subrelease_to_number(subrelease), version COLLATE version""", (pkg,)):
yield release, version
@@ -1685,7 +1686,7 @@ class DB:
p.version AS version, s.vulnerable AS vulnerable
FROM source_package_status AS s, source_packages AS p
WHERE s.bug_name = ? AND p.rowid = s.package
AND release in ('squeeze', 'wheezy', 'jessie', 'sid'))
GROUP BY package, version, vulnerable
ORDER BY package, releasepart_to_number(release), subreleasepart_to_number(release), version COLLATE version""",
(bug,)):
@@ -1734,7 +1735,7 @@ class DB:
st.urgency = 'unimportant' OR NOT vulnerable AS unimportant
FROM source_packages AS sp, source_package_status AS st, bugs
WHERE sp.name = ?
AND sp.release IN ('squeeze', 'wheezy', 'jessie', 'sid')
AND sp.subrelease <> 'security' AND sp.subrelease <> 'lts'
AND st.package = sp.rowid
AND bugs.name = st.bug_name
@@ -1630,7 +1631,7 @@ class DB:
AS release, version FROM source_packages
WHERE name = ?
- AND release IN ('squeeze', 'wheezy', 'jessie', 'sid')
+ AND release IN ('squeeze', 'wheezy', 'jessie', 'stretch', 'sid')
GROUP BY release, version
ORDER BY release_to_number(release), subrelease_to_number(subrelease), version COLLATE version""", (pkg,)):
@@ -1685,7 +1686,7 @@ class DB:
FROM source_package_status AS s, source_packages AS p
WHERE s.bug_name = ? AND p.rowid = s.package
- AND release in ('squeeze', 'wheezy', 'jessie', 'sid'))
+ AND release in ('squeeze', 'wheezy', 'jessie', 'stretch', 'sid'))
GROUP BY package, version, vulnerable
ORDER BY package, releasepart_to_number(release), subreleasepart_to_number(release), version COLLATE version""",
@@ -1734,7 +1735,7 @@ class DB:
FROM source_packages AS sp, source_package_status AS st, bugs
WHERE sp.name = ?
- AND sp.release IN ('squeeze', 'wheezy', 'jessie', 'sid')
+ AND sp.release IN ('squeeze', 'wheezy', 'jessie', 'stretch', 'sid')
AND sp.subrelease <> 'security' AND sp.subrelease <> 'lts'
AND st.package = sp.rowid

© 2014-2024 Faster IT GmbH | imprint | privacy policy